;; Generated package description from futur.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "futur" "1.2.0.20260311.142047" "Future/promise-based async library" 'nil :commit "576376047c87c4ffd1c653a8a0f75dafc181b4d1" :url "https://elpa.gnu.org/packages/futur.html" :authors '(("Stefan Monnier" . "monnier@iro.umontreal.ca")) :maintainer '("Stefan Monnier" . "monnier@iro.umontreal.ca") :keywords '("concurrency" "async" "promises" "futures"))
